# Auxillary data for json_parse_tests.bzl, kept here to simply neaten
# up the test file.

def get_pkg_jsons():
    return {
        "rollup": """{
  "name": "rollup",
  "version": "0.57.1",
  "description": "Next-generation ES6 module bundler",
  "main": "dist/rollup.js",
  "module": "dist/rollup.es.js",
  "jsnext:main": "dist/rollup.es.js",
  "typings": "dist/typings/node-entry.d.ts",
  "bin": {
    "rollup": "./bin/rollup"
  },
  "scripts": {
    "pretest": "npm run build",
    "test": "npm run test:only && npm run test:typescript",
    "test:only": "mocha",
    "test:leak": "node --expose-gc test/leak/index.js",
    "test:quick": "mocha -b",
    "pretest:typescript": "rm -rf test/typescript/dist && rm -rf test/typescript/typings && cp -r dist test/typescript/ && cp -r typings test/typescript/",
    "test:typescript": "tsc -p test/typescript",
    "pretest-coverage": "npm run build",
    "test-coverage": "rm -rf coverage/* && istanbul cover --report json node_modules/.bin/_mocha -- -u exports -R spec test/test.js",
    "posttest-coverage": "remap-istanbul -i coverage/coverage-final.json -o coverage/coverage-remapped.json -b dist && remap-istanbul -i coverage/coverage-final.json -o coverage/coverage-remapped.lcov -t lcovonly -b dist && remap-istanbul -i coverage/coverage-final.json -o coverage/coverage-remapped -t html -b dist",
    "ci": "npm run test-coverage && codecov < coverage/coverage-remapped.lcov",
    "prebuild": "rm -rf dist",
    "build": "git rev-parse HEAD > .commithash && rollup -c && tsc -p tsconfig-types.json && chmod a+x bin/rollup",
    "watch": "rollup -cw",
    "prepublishOnly": "npm run lint && npm run test && npm run test:leak",
    "prepare": "npm run build",
    "lint": "eslint src browser bin test/test.js test/*/index.js test/utils test/**/_config.js",
    "precommit": "lint-staged",
    "postcommit": "git reset",
    "perf": "node --expose-gc scripts/perf.js",
    "perf:init": "node scripts/perf-init.js",
    "perf:debug": "node --inspect-brk scripts/perf-debug.js"
  },
  "repository": "rollup/rollup",
  "keywords": [
    "modules",
    "bundler",
    "bundling",
    "es6",
    "optimizer"
  ],
  "author": "Rich Harris",
  "contributors": [
    "Oskar Segersvärd <victorystick@gmail.com>",
    "Bogdan Chadkin <trysound@yandex.ru>"
  ],
  "license": "MIT",
  "bugs": {
    "url": "https://github.com/rollup/rollup/issues"
  },
  "homepage": "https://github.com/rollup/rollup",
  "dependencies": {
    "@types/acorn": "^4.0.3",
    "acorn": "^5.5.3",
    "acorn-dynamic-import": "^3.0.0",
    "locate-character": "^2.0.5",
    "pretty-ms": "^3.1.0",
    "signal-exit": "^3.0.2",
    "date-time": "^2.1.0",
    "is-reference": "^1.1.0",
    "sourcemap-codec": "^1.4.1",
    "require-relative": "^0.8.7",
    "rollup-pluginutils": "^2.0.1"
  },
  "devDependencies": {
    "@types/chokidar": "^1.7.5",
    "@types/minimist": "^1.2.0",
    "@types/node": "^9.4.7",
    "@types/pretty-ms": "^3.0.0",
    "ansi-escapes": "^3.0.0",
    "buble": "^0.19.3",
    "cash-cp": "^0.2.0",
    "cash-rm": "^0.2.0",
    "chalk": "^2.3.2",
    "codecov.io": "^0.1.6",
    "console-group": "^0.3.1",
    "eslint": "^4.18.2",
    "eslint-plugin-import": "^2.9.0",
    "execa": "^0.9.0",
    "fixturify": "^0.3.4",
    "husky": "^0.14.3",
    "immutable": "^3.8.2",
    "istanbul": "^0.4.3",
    "lint-staged": "^7.0.0",
    "magic-string": "^0.23.2",
    "minimist": "^1.2.0",
    "mocha": "^5.0.4",
    "prettier": "^1.10.2",
    "remap-istanbul": "^0.10.1",
    "rollup": "^0.56.5",
    "rollup-plugin-buble": "^0.19.2",
    "rollup-plugin-commonjs": "^9.1.0",
    "rollup-plugin-json": "^2.3.0",
    "rollup-plugin-node-resolve": "^3.2.0",
    "rollup-plugin-replace": "^2.0.0",
    "rollup-plugin-string": "^2.0.0",
    "rollup-plugin-typescript": "^0.8.1",
    "rollup-watch": "^4.3.1",
    "sander": "^0.6.0",
    "source-map": "^0.6.1",
    "source-map-support": "^0.5.3",
    "typescript": "^2.7.2",
    "uglify-js": "^3.3.14"
  },
  "files": [
    "dist/rollup.browser.js",
    "dist/rollup.es.js",
    "dist/rollup.js",
    "dist/**/*.d.ts",
    "typings/package.json.d.ts",
    "bin/rollup",
    "README.md"
  ],
  "lint-staged": {
    "*.ts": [
      "prettier --write",
      "git add"
    ]
  }
}
""",
        "lodash": """{
  "name": "lodash",
  "version": "4.17.4",
  "license": "MIT",
  "private": true,
  "main": "lodash.js",
  "engines": {
    "node": ">=4.0.0"
  },
  "sideEffects": false,
  "scripts": {
    "build": "npm run build:main && npm run build:fp",
    "build:fp": "node lib/fp/build-dist.js",
    "build:fp-modules": "node lib/fp/build-modules.js",
    "build:main": "node lib/main/build-dist.js",
    "build:main-modules": "node lib/main/build-modules.js",
    "doc": "node lib/main/build-doc github && npm run test:doc",
    "doc:fp": "node lib/fp/build-doc",
    "doc:site": "node lib/main/build-doc site",
    "doc:sitehtml": "optional-dev-dependency marky-markdown@^9.0.1 && npm run doc:site && node lib/main/build-site",
    "pretest": "npm run build",
    "style": "eslint *.js .internal/**/*.js",
    "test": "npm run test:main && npm run test:fp",
    "test:doc": "markdown-doctest doc/*.md",
    "test:fp": "node test/test-fp",
    "test:main": "node test/test",
    "validate": "npm run style && npm run test"
  },
  "devDependencies": {
    "async": "^2.1.4",
    "benchmark": "^2.1.3",
    "chalk": "^1.1.3",
    "cheerio": "^0.22.0",
    "codecov.io": "~0.1.6",
    "coveralls": "^2.11.15",
    "curl-amd": "~0.8.12",
    "docdown": "~0.7.2",
    "dojo": "^1.12.1",
    "ecstatic": "^2.1.0",
    "eslint": "^3.15.0",
    "eslint-plugin-import": "^2.2.0",
    "fs-extra": "~1.0.0",
    "glob": "^7.1.1",
    "istanbul": "0.4.5",
    "jquery": "^3.1.1",
    "lodash": "4.17.3",
    "lodash-doc-globals": "^0.1.1",
    "markdown-doctest": "^0.9.1",
    "optional-dev-dependency": "^2.0.0",
    "platform": "^1.3.3",
    "qunit-extras": "^3.0.0",
    "qunitjs": "^2.1.0",
    "request": "^2.79.0",
    "requirejs": "^2.3.2",
    "sauce-tunnel": "^2.5.0",
    "uglify-js": "2.7.5",
    "webpack": "^1.14.0"
  },
  "greenkeeper": {
    "ignore": [
      "lodash"
    ]
  }
}
""",
        "express": """{
  "name": "express",
  "description": "Fast, unopinionated, minimalist web framework",
  "version": "4.16.3",
  "author": "TJ Holowaychuk <tj@vision-media.ca>",
  "contributors": [
    "Aaron Heckmann <aaron.heckmann+github@gmail.com>",
    "Ciaran Jessup <ciaranj@gmail.com>",
    "Douglas Christopher Wilson <doug@somethingdoug.com>",
    "Guillermo Rauch <rauchg@gmail.com>",
    "Jonathan Ong <me@jongleberry.com>",
    "Roman Shtylman <shtylman+expressjs@gmail.com>",
    "Young Jae Sim <hanul@hanul.me>"
  ],
  "license": "MIT",
  "repository": "expressjs/express",
  "homepage": "http://expressjs.com/",
  "keywords": [
    "express",
    "framework",
    "sinatra",
    "web",
    "rest",
    "restful",
    "router",
    "app",
    "api"
  ],
  "dependencies": {
    "accepts": "~1.3.5",
    "array-flatten": "1.1.1",
    "body-parser": "1.18.2",
    "content-disposition": "0.5.2",
    "content-type": "~1.0.4",
    "cookie": "0.3.1",
    "cookie-signature": "1.0.6",
    "debug": "2.6.9",
    "depd": "~1.1.2",
    "encodeurl": "~1.0.2",
    "escape-html": "~1.0.3",
    "etag": "~1.8.1",
    "finalhandler": "1.1.1",
    "fresh": "0.5.2",
    "merge-descriptors": "1.0.1",
    "methods": "~1.1.2",
    "on-finished": "~2.3.0",
    "parseurl": "~1.3.2",
    "path-to-regexp": "0.1.7",
    "proxy-addr": "~2.0.3",
    "qs": "6.5.1",
    "range-parser": "~1.2.0",
    "safe-buffer": "5.1.1",
    "send": "0.16.2",
    "serve-static": "1.13.2",
    "setprototypeof": "1.1.0",
    "statuses": "~1.4.0",
    "type-is": "~1.6.16",
    "utils-merge": "1.0.1",
    "vary": "~1.1.2"
  },
  "devDependencies": {
    "after": "0.8.2",
    "cookie-parser": "~1.4.3",
    "cookie-session": "1.3.2",
    "ejs": "2.5.7",
    "eslint": "2.13.1",
    "express-session": "1.15.6",
    "hbs": "4.0.1",
    "istanbul": "0.4.5",
    "marked": "0.3.17",
    "method-override": "2.3.10",
    "mocha": "3.5.3",
    "morgan": "1.9.0",
    "multiparty": "4.1.3",
    "pbkdf2-password": "1.2.1",
    "should": "13.2.1",
    "supertest": "1.2.0",
    "connect-redis": "~2.4.1",
    "vhost": "~3.0.2"
  },
  "engines": {
    "node": ">= 0.10.0"
  },
  "files": [
    "LICENSE",
    "History.md",
    "Readme.md",
    "index.js",
    "lib/"
  ],
  "scripts": {
    "lint": "eslint .",
    "test": "mocha --require test/support/env --reporter spec --bail --check-leaks --no-exit test/ test/acceptance/",
    "test-ci": "istanbul cover node_modules/mocha/bin/_mocha --report lcovonly -- --require test/support/env --reporter spec --check-leaks --no-exit test/ test/acceptance/",
    "test-cov": "istanbul cover node_modules/mocha/bin/_mocha -- --require test/support/env --reporter dot --check-leaks --no-exit test/ test/acceptance/",
    "test-tap": "mocha --require test/support/env --reporter tap --check-leaks --no-exit test/ test/acceptance/"
  }
}
""",
        "react": """{
  "private": true,
  "version": "16.3.0-alpha.2",
  "workspaces": [
    "packages/*"
  ],
  "devDependencies": {
    "art": "^0.10.1",
    "async": "^1.5.0",
    "babel-cli": "^6.6.5",
    "babel-code-frame": "^6.26.0",
    "babel-core": "^6.0.0",
    "babel-eslint": "^8.0.0",
    "babel-jest": "^22.0.6",
    "babel-plugin-check-es2015-constants": "^6.5.0",
    "babel-plugin-external-helpers": "^6.22.0",
    "babel-plugin-syntax-trailing-function-commas": "^6.5.0",
    "babel-plugin-transform-async-to-generator": "^6.22.0",
    "babel-plugin-transform-class-properties": "^6.11.5",
    "babel-plugin-transform-es2015-arrow-functions": "^6.5.2",
    "babel-plugin-transform-es2015-block-scoped-functions": "^6.5.0",
    "babel-plugin-transform-es2015-block-scoping": "^6.23.0",
    "babel-plugin-transform-es2015-classes": "^6.5.2",
    "babel-plugin-transform-es2015-computed-properties": "^6.5.2",
    "babel-plugin-transform-es2015-destructuring": "^6.5.0",
    "babel-plugin-transform-es2015-for-of": "^6.5.2",
    "babel-plugin-transform-es2015-literals": "^6.5.0",
    "babel-plugin-transform-es2015-modules-commonjs": "^6.5.2",
    "babel-plugin-transform-es2015-object-super": "^6.5.0",
    "babel-plugin-transform-es2015-parameters": "^6.5.0",
    "babel-plugin-transform-es2015-shorthand-properties": "^6.5.0",
    "babel-plugin-transform-es2015-spread": "^6.5.2",
    "babel-plugin-transform-es2015-template-literals": "^6.5.2",
    "babel-plugin-transform-es3-member-expression-literals": "^6.5.0",
    "babel-plugin-transform-es3-property-literals": "^6.5.0",
    "babel-plugin-transform-object-rest-spread": "^6.6.5",
    "babel-plugin-transform-react-jsx-source": "^6.8.0",
    "babel-plugin-transform-regenerator": "^6.26.0",
    "babel-preset-react": "^6.5.0",
    "babel-traverse": "^6.9.0",
    "babylon": "6.15.0",
    "bundle-collapser": "^1.1.1",
    "chalk": "^1.1.3",
    "cli-table": "^0.3.1",
    "coffee-script": "^1.8.0",
    "core-js": "^2.2.1",
    "coveralls": "^2.11.6",
    "create-react-class": "^15.6.3",
    "cross-env": "^5.1.1",
    "danger": "^3.0.4",
    "del": "^2.0.2",
    "derequire": "^2.0.3",
    "escape-string-regexp": "^1.0.5",
    "eslint": "^4.1.0",
    "eslint-config-fbjs": "^1.1.1",
    "eslint-plugin-babel": "^3.3.0",
    "eslint-plugin-flowtype": "^2.25.0",
    "eslint-plugin-jest": "^21.6.1",
    "eslint-plugin-no-for-of-loops": "^1.0.0",
    "eslint-plugin-react": "^6.7.1",
    "eslint-plugin-react-internal": "link:./scripts/eslint-rules/",
    "fbjs": "^0.8.16",
    "fbjs-scripts": "^0.6.0",
    "filesize": "^3.5.6",
    "flow-bin": "^0.61.0",
    "flow-coverage-report": "^0.4.0",
    "git-branch": "^0.3.0",
    "glob": "^6.0.4",
    "glob-stream": "^6.1.0",
    "gzip-js": "~0.3.2",
    "gzip-size": "^3.0.0",
    "jasmine-check": "^1.0.0-rc.0",
    "jest": "^22.0.6",
    "jest-diff": "^22.1.0",
    "merge-stream": "^1.0.0",
    "minimatch": "^3.0.4",
    "minimist": "^1.2.0",
    "mkdirp": "^0.5.1",
    "ncp": "^2.0.0",
    "object-assign": "^4.1.1",
    "platform": "^1.1.0",
    "prettier": "1.8.1",
    "prop-types": "^15.6.0",
    "random-seed": "^0.3.0",
    "react-lifecycles-compat": "^1.0.2",
    "rimraf": "^2.6.1",
    "rollup": "^0.52.1",
    "rollup-plugin-babel": "^3.0.1",
    "rollup-plugin-closure-compiler-js": "^1.0.6",
    "rollup-plugin-commonjs": "^8.2.6",
    "rollup-plugin-node-resolve": "^2.1.1",
    "rollup-plugin-prettier": "^0.3.0",
    "rollup-plugin-replace": "^2.0.0",
    "rollup-plugin-strip-banner": "^0.2.0",
    "run-sequence": "^1.1.4",
    "targz": "^1.0.1",
    "through2": "^2.0.0",
    "tmp": "~0.0.28",
    "typescript": "~1.8.10",
    "yargs": "^6.3.0"
  },
  "devEngines": {
    "node": "8.x || 9.x"
  },
  "scripts": {
    "build": "npm run version-check && node ./scripts/rollup/build.js",
    "flow-coverage": "flow-coverage-report --config ./.flowcoverage",
    "linc": "node ./scripts/tasks/linc.js",
    "lint": "node ./scripts/tasks/eslint.js",
    "lint-build": "node ./scripts/rollup/validate/index.js",
    "postinstall": "node node_modules/fbjs-scripts/node/check-dev-engines.js package.json",
    "debug-test": "cross-env NODE_ENV=development node --inspect-brk node_modules/.bin/jest --config ./scripts/jest/config.source.js --runInBand",
    "test": "cross-env NODE_ENV=development jest --config ./scripts/jest/config.source.js",
    "test-prod": "cross-env NODE_ENV=production jest --config ./scripts/jest/config.source.js",
    "test-prod-build": "yarn test-build-prod",
    "test-build": "cross-env NODE_ENV=development jest --config ./scripts/jest/config.build.js",
    "test-build-prod": "cross-env NODE_ENV=production jest --config ./scripts/jest/config.build.js",
    "flow": "node ./scripts/tasks/flow.js",
    "prettier": "node ./scripts/prettier/index.js write-changed",
    "prettier-all": "node ./scripts/prettier/index.js write",
    "version-check": "node ./scripts/tasks/version-check.js"
  }
}
""",
        "jquery": """{
  "name": "jquery",
  "title": "jQuery",
  "description": "JavaScript library for DOM operations",
  "version": "3.3.2-pre",
  "main": "dist/jquery.js",
  "homepage": "https://jquery.com",
  "author": {
    "name": "JS Foundation and other contributors",
    "url": "https://github.com/jquery/jquery/blob/master/AUTHORS.txt"
  },
  "repository": {
    "type": "git",
    "url": "https://github.com/jquery/jquery.git"
  },
  "keywords": [
    "jquery",
    "javascript",
    "browser",
    "library"
  ],
  "bugs": {
    "url": "https://github.com/jquery/jquery/issues"
  },
  "license": "MIT",
  "dependencies": {},
  "devDependencies": {
    "babel-core": "7.0.0-beta.0",
    "babel-plugin-transform-es2015-for-of": "7.0.0-beta.0",
    "commitplease": "2.7.10",
    "core-js": "2.4.1",
    "eslint-config-jquery": "1.0.1",
    "grunt": "1.0.1",
    "grunt-babel": "7.0.0",
    "grunt-cli": "1.2.0",
    "grunt-compare-size": "0.4.2",
    "grunt-contrib-uglify": "3.0.1",
    "grunt-contrib-watch": "1.0.0",
    "grunt-eslint": "20.0.0",
    "grunt-git-authors": "3.2.0",
    "grunt-jsonlint": "1.1.0",
    "grunt-karma": "2.0.0",
    "grunt-newer": "1.3.0",
    "grunt-npmcopy": "0.1.0",
    "gzip-js": "0.3.2",
    "husky": "0.14.3",
    "insight": "0.8.4",
    "jsdom": "5.6.1",
    "karma": "1.7.0",
    "karma-browserstack-launcher": "1.3.0",
    "karma-chrome-launcher": "2.2.0",
    "karma-firefox-launcher": "1.0.1",
    "karma-qunit": "1.2.1",
    "load-grunt-tasks": "3.5.2",
    "native-promise-only": "0.8.1",
    "promises-aplus-tests": "2.1.2",
    "q": "1.5.0",
    "qunit-assert-step": "1.0.3",
    "qunitjs": "1.23.1",
    "raw-body": "2.2.0",
    "requirejs": "2.3.3",
    "sinon": "2.3.7",
    "sizzle": "2.3.3",
    "strip-json-comments": "2.0.1",
    "testswarm": "1.1.0",
    "uglify-js": "3.3.12"
  },
  "scripts": {
    "build": "npm install && grunt",
    "start": "grunt watch",
    "test:browserless": "grunt && grunt test:slow",
    "test:browser": "grunt && grunt karma:main",
    "test": "grunt && grunt test:slow && grunt karma:main",
    "jenkins": "npm run test:browserless",
    "precommit": "grunt lint:newer qunit_fixture",
    "commitmsg": "node node_modules/commitplease"
  },
  "commitplease": {
    "nohook": true,
    "components": [
      "Docs",
      "Tests",
      "Build",
      "Support",
      "Release",
      "Core",
      "Ajax",
      "Attributes",
      "Callbacks",
      "CSS",
      "Data",
      "Deferred",
      "Deprecated",
      "Dimensions",
      "Effects",
      "Event",
      "Manipulation",
      "Offset",
      "Queue",
      "Selector",
      "Serialize",
      "Traversing",
      "Wrap"
    ],
    "markerPattern": "^((clos|fix|resolv)(e[sd]|ing))|^(refs?)",
    "ticketPattern": "^((Closes|Fixes) ([a-zA-Z]{2,}-)[0-9]+)|^(Refs? [^#])"
  }
}
""",
        "q": """{
  "name": "q",
  "version": "1.5.1",
  "description": "A library for promises (CommonJS/Promises/A,B,D)",
  "homepage": "https://github.com/kriskowal/q",
  "author": "Kris Kowal <kris@cixar.com> (https://github.com/kriskowal)",
  "keywords": [
    "q",
    "promise",
    "promises",
    "promises-a",
    "promises-aplus",
    "deferred",
    "future",
    "async",
    "flow control",
    "fluent",
    "browser",
    "node"
  ],
  "contributors": [
    "Kris Kowal <kris@cixar.com> (https://github.com/kriskowal)",
    "Irakli Gozalishvili <rfobic@gmail.com> (http://jeditoolkit.com)",
    "Domenic Denicola <domenic@domenicdenicola.com> (http://domenicdenicola.com)"
  ],
  "bugs": {
    "mail": "kris@cixar.com",
    "url": "http://github.com/kriskowal/q/issues"
  },
  "license": "MIT",
  "main": "q.js",
  "files": [
    "LICENSE",
    "q.js",
    "queue.js"
  ],
  "repository": {
    "type": "git",
    "url": "git://github.com/kriskowal/q.git"
  },
  "engines": {
    "node": ">=0.6.0",
    "teleport": ">=0.2.0"
  },
  "dependencies": {},
  "devDependencies": {
    "cover": "*",
    "grunt": "~0.4.1",
    "grunt-cli": "~0.1.9",
    "grunt-contrib-uglify": "~0.9.1",
    "jasmine-node": "1.11.0",
    "jshint": "~2.1.9",
    "matcha": "~0.2.0",
    "opener": "*",
    "promises-aplus-tests": "1.x"
  },
  "scripts": {
    "test": "npm ls -s && jasmine-node spec && promises-aplus-tests spec/aplus-adapter && npm run -s lint",
    "test-browser": "opener spec/q-spec.html",
    "benchmark": "matcha",
    "lint": "jshint q.js",
    "cover": "cover run jasmine-node spec && cover report html && opener cover_html/index.html",
    "minify": "grunt",
    "prepublish": "grunt"
  },
  "overlay": {
    "teleport": {
      "dependencies": {
        "system": ">=0.0.4"
      }
    }
  },
  "directories": {
    "test": "./spec"
  }
}
""",
        # YUCK!!! NOTE the raw literal quoting, to avoid double
        # escaping the backslash escaped quotes below.
        "rxjs": r'''{
  "name": "@reactivex/rxjs",
  "version": "6.0.0-beta.0",
  "description": "Reactive Extensions for modern JavaScript",
  "main": "index.js",
  "sideEffects": false,
  "config": {
    "commitizen": {
      "path": "cz-conventional-changelog"
    }
  },
  "nyc": {
    "include": [
      "src/*.ts",
      "src/**/*.ts"
    ],
    "exclude": [
      "node_modules",
      "dist",
      "*.d.ts",
      "src/**/MiscJSDoc.ts"
    ],
    "extension": [
      ".ts"
    ],
    "require": [
      "ts-node/register"
    ],
    "reporter": [
      "html"
    ],
    "all": true
  },
  "lint-staged": {
    "*.@(js)": [
      "eslint --fix",
      "git add"
    ],
    "*.@(ts)": [
      "tslint --fix",
      "git add"
    ]
  },
  "scripts-info": {
    "info": "List available script",
    "build_all": "Build all packages (ES6, CJS, UMD) and generate packages",
    "build_cjs": "Build CJS package with clean up existing build",
    "build_esm5": "Build ESM/ES5 package with clean up existing build",
    "build_esm2015": "Build ESM/ES2015 package with clean up existing build",
    "build_closure_core": "Minify Global core build using closure compiler",
    "build_global": "Build Global package, then minify build",
    "build_perf": "Build CJS & Global build, run macro performance test",
    "build_docs": "Build ESM2015 & global package, create documentation using it",
    "clean_dist_cjs": "Clean up existing CJS package output",
    "clean_dist_esm5": "Clean up existing ESM/ES5 package output",
    "clean_dist_esm2015": "Clean up existing ESM/ES2015 package output",
    "clean_dist_global": "Clean up existing Global package output",
    "commit": "Run git commit wizard",
    "compile_dist_cjs": "Compile codebase into CJS module",
    "compile_module_esm5": "Compile codebase into ESM/ES5",
    "compile_dist_esm2015": "Compile codebase into ESM/ES2015",
    "lint_perf": "Run lint against performance test suite",
    "lint_spec": "Run lint against test spec",
    "lint_src": "Run lint against source",
    "lint": "Run lint against everything",
    "perf": "Run macro performance benchmark",
    "perf_micro": "Run micro performance benchmark",
    "test_browser": "Execute mocha test runner on browser against existing test spec build",
    "test": "Execute mocha test runner",
    "test:cover": "Execute test coverage",
    "tests2png": "Generate marble diagram image from test spec",
    "watch": "Watch codebase, trigger compile when source code changes"
  },
  "scripts": {
    "precommit": "lint-staged",
    "commitmsg": "validate-commit-msg",
    "info": "npm-scripts-info",
    "build_all": "npm-run-all compat_build_all clean_dist copy_sources build_cjs build_esm5 build_esm2015 build_esm5_for_rollup build_umd build_legacy_reexport generate_packages copy_for_tests",
    "build_cjs": "npm-run-all clean_dist_cjs compile_dist_cjs",
    "build_esm5": "npm-run-all clean_dist_esm5 compile_dist_esm5",
    "build_esm5_for_rollup": "npm-run-all clean_dist_esm5_for_rollup compile_dist_esm5_for_rollup && mkdirp dist/esm5_for_rollup/node_modules && shx cp -r ./dist-compat/package ./dist/esm5_for_rollup/node_modules/rxjs-compat",
    "build_esm2015": "npm-run-all clean_dist_esm2015 compile_dist_esm2015",
    "build_esm2015_for_docs": "npm-run-all clean_dist_esm2015 compile_dist_esm2015_for_docs",
    "build_legacy_reexport": "npm-run-all compile_legacy_reexport",
    "build_closure_core": "node ./tools/make-closure-core.js",
    "build_global": "npm-run-all clean_dist_global build_esm5_for_rollup && mkdirp ./dist/global && node ./tools/make-umd-bundle.js && npm-run-all build_closure_core clean_dist_esm5_for_rollup",
    "build_umd": "npm-run-all clean_dist_global && mkdirp ./dist/global && node ./tools/make-umd-bundle.js && npm-run-all build_closure_core",
    "build_perf": "webdriver-manager update && npm-run-all build_cjs build_global perf",
    "build_docs": "npm-run-all build_global build_esm2015_for_docs build_cjs tests2png decision_tree_widget && esdoc -c esdoc.json && npm-run-all clean_dist_esm2015",
    "build_spec": "npm-run-all build_cjs generate_packages copy_for_tests",
    "build_spec_full": "npm-run-all compat_build_cjs compile_legacy_reexport compat_generate_packages build_spec",
    "build_spec_browser": "webpack --config spec/support/webpack.mocha.config.js",
    "clean_dist": "shx rm -rf ./dist",
    "clean_dist_cjs": "shx rm -rf ./dist/cjs",
    "clean_dist_esm5": "shx rm -rf ./dist/esm5",
    "clean_dist_esm5_for_rollup": "shx rm -rf ./dist/esm5_for_rollup",
    "clean_dist_esm2015": "shx rm -rf ./dist/esm2015",
    "clean_dist_global": "shx rm -rf ./dist/global",
    "commit": "git-cz",
    "compile_dist_cjs": "tsc -p ./tsconfig/tsconfig.cjs.json",
    "compile_dist_esm5": "tsc -p ./tsconfig/tsconfig.esm5.json",
    "compile_dist_esm2015": "tsc -p ./tsconfig/tsconfig.esm2015.json",
    "compile_dist_esm2015_for_docs": "tsc ./dist/src/internal/Rx.ts ./dist/src/add/observable/of.ts ./dist/src/MiscJSDoc.ts -m es2015   --sourceMap --outDir ./dist/es6 --target es2015 -d --diagnostics --pretty --noImplicitAny --noImplicitReturns --noImplicitThis --suppressImplicitAnyIndexErrors --moduleResolution node",
    "compile_dist_esm5_for_rollup": "tsc -p ./tsconfig/tsconfig.esm5.rollup.json",
    "compile_legacy_reexport": "tsc -p ./tsconfig/tsconfig.legacy-reexport.json",
    "copy_sources": "mkdirp dist && shx cp -r ./src/ ./dist/src",
    "copy_for_tests": "shx rm -rf ./spec-build && shx cp -r ./spec/ ./spec-build/ && mkdirp ./spec-build/node_modules && shx cp -r ./dist/package/ ./spec-build/node_modules/rxjs && shx cp -r ./dist-compat/package/ ./spec-build/node_modules/rxjs-compat",
    "decision_tree_widget": "cd doc/decision-tree-widget && npm run build && cd ../..",
    "doctoc": "doctoc CONTRIBUTING.md",
    "generate_packages": "node .make-packages.js",
    "lint_perf": "eslint perf/",
    "lint_spec": "tslint -c tslint.json \"spec/**/*.ts\"",
    "lint_src": "tslint -c tslint.json \"src/**/*.ts\"",
    "lint": "npm-run-all --parallel lint_*",
    "perf": "protractor protractor.conf.js",
    "perf_micro": "node ./perf/micro/index.js",
    "prepublish": "shx rm -rf ./typings && npm run build_all",
    "publish_docs": "./publish_docs.sh",
    "test_browser": "npm-run-all build_spec_browser && opn spec/support/mocha-browser-runner.html",
    "test": "cross-env TS_NODE_FAST=true mocha --require ts-node/register --opts spec-build/support/coverage.opts \"spec-build/**/*-spec.ts\"",
    "test:cover": "cross-env TS_NODE_FAST=true nyc npm test",
    "test:circular": "dependency-cruise --validate .dependency-cruiser.json -x \"^node_modules\" src",
    "test:systemjs": "node integration/systemjs/systemjs-compatibility-spec.js",
    "tests2png": "mkdirp tmp/docs/img && cross-env TS_NODE_FAST=true mocha --compilers ts:ts-node/register --opts spec/support/tests2png.opts \"spec/**/*-spec.ts\"",
    "watch": "watch \"echo triggering build && npm run build_spec && npm run test && echo build completed\" src -d -u -w=15",
    "compat_build_all": "npm-run-all compat_clean_dist compat_build_cjs compat_build_esm5 compat_build_esm2015 compat_generate_packages",
    "compat_build_cjs": "npm-run-all compat_clean_dist_cjs compat_compile_dist_cjs",
    "compat_build_esm5": "npm-run-all compat_clean_dist_esm5 compat_compile_dist_esm5",
    "compat_build_esm2015": "npm-run-all compat_clean_dist_esm2015 compat_compile_dist_esm2015",
    "compat_clean_dist": "shx rm -rf ./dist-compat",
    "compat_clean_dist_cjs": "shx rm -rf ./dist-compat/cjs",
    "compat_clean_dist_esm5": "shx rm -rf ./dist-compat/esm5",
    "compat_clean_dist_esm2015": "shx rm -rf ./dist-compat/esm2015",
    "compat_compile_dist_cjs": "tsc -p ./tsconfig/compat/tsconfig.cjs.json",
    "compat_compile_dist_esm5": "tsc -p ./tsconfig/compat/tsconfig.esm5.json",
    "compat_compile_dist_esm2015": "tsc -p ./tsconfig/compat/tsconfig.esm2015.json",
    "compat_copy_sources": "mkdirp dist-compat && shx cp -r ./compat/ ./dist-compat/",
    "compat_generate_packages": "node .make-compat-package.js"
  },
  "repository": {
    "type": "git",
    "url": "git@github.com:ReactiveX/RxJS.git"
  },
  "keywords": [
    "Rx",
    "RxJS",
    "ReactiveX",
    "ReactiveExtensions",
    "Streams",
    "Observables",
    "Observable",
    "Stream",
    "ES6",
    "ES2015"
  ],
  "author": "Ben Lesh <ben@benlesh.com>",
  "contributors": [
    {
      "name": "Ben Lesh",
      "email": "ben@benlesh.com"
    },
    {
      "name": "Paul Taylor",
      "email": "paul.e.taylor@me.com"
    },
    {
      "name": "Jeff Cross",
      "email": "crossj@google.com"
    },
    {
      "name": "Matthew Podwysocki",
      "email": "matthewp@microsoft.com"
    },
    {
      "name": "OJ Kwon",
      "email": "kwon.ohjoong@gmail.com"
    },
    {
      "name": "Andre Staltz",
      "email": "andre@staltz.com"
    }
  ],
  "license": "Apache-2.0",
  "bugs": {
    "url": "https://github.com/ReactiveX/RxJS/issues"
  },
  "homepage": "https://github.com/ReactiveX/RxJS",
  "dependencies": {
    "tslib": "^1.9.0"
  },
  "devDependencies": {
    "@angular-devkit/build-optimizer": "0.0.24",
    "@types/chai": "4.1.2",
    "@types/lodash": "4.14.102",
    "@types/mocha": "2.2.48",
    "@types/node": "9.4.5",
    "@types/sinon": "4.1.3",
    "@types/sinon-chai": "2.7.29",
    "babel-polyfill": "6.26.0",
    "benchmark": "2.1.0",
    "benchpress": "2.0.0-beta.1",
    "chai": "4.1.2",
    "color": "3.0.0",
    "colors": "1.1.2",
    "commitizen": "2.9.6",
    "coveralls": "3.0.0",
    "cross-env": "5.1.3",
    "cz-conventional-changelog": "1.2.0",
    "danger": "1.1.0",
    "dependency-cruiser": "2.13.0",
    "doctoc": "1.3.0",
    "escape-string-regexp": "1.0.5",
    "esdoc": "0.4.7",
    "eslint": "4.17.0",
    "fs-extra": "5.0.0",
    "get-folder-size": "1.0.1",
    "glob": "7.1.2",
    "gm": "1.23.1",
    "google-closure-compiler-js": "20170218.0.0",
    "gzip-size": "4.1.0",
    "http-server": "0.11.1",
    "husky": "0.14.3",
    "klaw-sync": "3.0.2",
    "lint-staged": "3.2.5",
    "lodash": "4.17.5",
    "markdown-doctest": "0.9.1",
    "minimist": "1.2.0",
    "mkdirp": "0.5.1",
    "mocha": "5.0.0",
    "mocha-in-sauce": "0.0.1",
    "npm-run-all": "4.1.2",
    "npm-scripts-info": "0.3.6",
    "nyc": "11.4.1",
    "opn-cli": "3.1.0",
    "platform": "1.3.5",
    "promise": "8.0.1",
    "protractor": "3.1.1",
    "rollup": "0.36.3",
    "rollup-plugin-inject": "2.0.0",
    "rollup-plugin-node-resolve": "2.0.0",
    "rx": "latest",
    "rxjs": "^5.5.7",
    "shx": "0.2.2",
    "sinon": "4.3.0",
    "sinon-chai": "2.14.0",
    "source-map-support": "0.5.3",
    "symbol-observable": "1.0.1",
    "systemjs": "^0.21.0",
    "ts-node": "4.1.0",
    "tslint": "5.9.1",
    "tslint-no-unused-expression-chai": "0.0.3",
    "typescript": "latest",
    "validate-commit-msg": "2.14.0",
    "watch": "1.0.2",
    "webpack": "1.13.1",
    "xmlhttprequest": "1.8.0"
  },
  "engines": {
    "npm": ">=2.0.0"
  },
  "typings": "./dist/package/Rx.d.ts"
}
''',
        "aws-sdk-js": """{
  "name": "aws-sdk",
  "description": "AWS SDK for JavaScript",
  "version": "2.211.0",
  "author": {
    "name": "Amazon Web Services",
    "email": "",
    "url": "https://aws.amazon.com/"
  },
  "homepage": "https://github.com/aws/aws-sdk-js",
  "contributors": [
    "Loren Segal <lsegal@amazon.com>",
    "Trevor Rowe <trevrowe@amazon.com>"
  ],
  "devDependencies": {
    "@types/node": "^6.0.46",
    "browserify": "13.1.0",
    "chai": "^3.0",
    "codecov": "^1.0.1",
    "coffee-script": "1.6.3",
    "coffeeify": "*",
    "cucumber": "0.5.x",
    "eslint": "1.x",
    "hash-test-vectors": "^1.3.2",
    "insert-module-globals": "^7.0.0",
    "istanbul": "*",
    "jasmine": "^2.5.3",
    "jasmine-core": "^2.5.2",
    "json-loader": "^0.5.4",
    "karma": "^1.4.1",
    "karma-jasmine": "^1.1.0",
    "karma-phantomjs-launcher": "1.0.2",
    "mocha": "^3.0.0",
    "phantomjs-prebuilt": "2.1.15",
    "repl.history": "*",
    "semver": "*",
    "typescript": "2.0.8",
    "uglify-js": "2.x",
    "webpack": "^1.15.0"
  },
  "dependencies": {
    "buffer": "4.9.1",
    "events": "^1.1.1",
    "jmespath": "0.15.0",
    "querystring": "0.2.0",
    "sax": "1.2.1",
    "url": "0.10.3",
    "uuid": "3.1.0",
    "xml2js": "0.4.17",
    "xmlbuilder": "4.2.1"
  },
  "main": "lib/aws.js",
  "browser": {
    "lib/aws.js": "./lib/browser.js",
    "fs": false,
    "./global.js": "./browser.js",
    "./lib/node_loader.js": "./lib/browser_loader.js"
  },
  "browserify": {
    "transform": "./dist-tools/transform.js"
  },
  "react-native": {
    "fs": "./lib/empty.js",
    "./lib/node_loader.js": "./lib/react-native-loader.js",
    "./lib/browser_loader.js": "./lib/react-native-loader.js",
    "./lib/core.js": "./dist/aws-sdk-core-react-native.js",
    "xml2js": "./dist/xml2js.js"
  },
  "directories": {
    "lib": "lib"
  },
  "types": "index.d.ts",
  "typings": "index.d.ts",
  "engines": {
    "node": ">= 0.8.0"
  },
  "repository": {
    "type": "git",
    "url": "git://github.com/aws/aws-sdk-js"
  },
  "bugs": {
    "url": "https://github.com/aws/aws-sdk-js/issues",
    "mail": ""
  },
  "license": "Apache-2.0",
  "keywords": [
    "api",
    "amazon",
    "aws",
    "ec2",
    "simpledb",
    "s3",
    "sqs",
    "ses",
    "sns",
    "route53",
    "rds",
    "elasticache",
    "cloudfront",
    "fps",
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "iam",
    "swf",
    "autoscaling",
    "cloudsearch",
    "elb",
    "loadbalancing",
    "emr",
    "mapreduce",
    "importexport",
    "storagegateway",
    "workflow",
    "ebs",
    "vpc",
    "beanstalk",
    "glacier",
    "kinesis",
    "cloudtrail",
    "waf"
  ],
  "scripts": {
    "test": "npm -s run-script lint && npm -s run-script unit && npm -s run-script buildertest && npm -s run-script browsertest && npm -s run-script react-native-test && ([ -f configuration ] && npm -s run-script integration || true)",
    "unit": "mocha -- test test/json test/model test/protocol test/query test/services test/signers test/xml test/s3 test/cloudfront test/dynamodb test/polly test/rds",
    "coverage": "istanbul cover ./node_modules/mocha/bin/_mocha --reporter=lcovonly -- test test/json test/model test/protocol test/query test/services test/signers test/xml test/s3 test/cloudfront test/dynamodb test/polly test/rds",
    "browsertest": "rake browser:test && karma start",
    "buildertest": "mocha --compilers coffee:coffee-script -s 1000 -t 10000 dist-tools/test",
    "integration": "cucumber.js",
    "lint": "eslint lib dist-tools/*.js",
    "console": "./scripts/console",
    "testfiles": "istanbul `[ $COVERAGE ] && echo 'cover _mocha' || echo 'test mocha'`",
    "tstest": "tsc -p ./ts",
    "add-change": "node ./scripts/changelog/add-change.js",
    "build-react-native-deps": "webpack --config dist-tools/webpack.config.rn-dep.js",
    "build-react-native-core": "webpack --config dist-tools/webpack.config.rn-core.js",
    "build-react-native-dist": "webpack --config dist-tools/webpack.config.rn.js",
    "build-react-native": "npm -s run-script build-react-native-deps && npm -s run-script build-react-native-core && npm -s run-script build-react-native-dist",
    "react-native-test": "npm -s run-script build-react-native && rake reactnative:test && karma start",
    "region-check": "node ./scripts/region-checker/index.js"
  }
}
""",
        "webpack": r"""{
  "name": "webpack",
  "version": "4.1.1",
  "author": "Tobias Koppers @sokra",
  "description": "Packs CommonJs/AMD modules for the browser. Allows to split your codebase into multiple bundles, which can be loaded on demand. Support loaders to preprocess files, i.e. json, jsx, es7, css, less, ... and your custom stuff.",
  "license": "MIT",
  "dependencies": {
    "acorn": "^5.0.0",
    "acorn-dynamic-import": "^3.0.0",
    "ajv": "^6.1.0",
    "ajv-keywords": "^3.1.0",
    "chrome-trace-event": "^0.1.1",
    "enhanced-resolve": "^4.0.0",
    "eslint-scope": "^3.7.1",
    "loader-runner": "^2.3.0",
    "loader-utils": "^1.1.0",
    "memory-fs": "~0.4.1",
    "micromatch": "^3.1.8",
    "mkdirp": "~0.5.0",
    "neo-async": "^2.5.0",
    "node-libs-browser": "^2.0.0",
    "schema-utils": "^0.4.2",
    "tapable": "^1.0.0",
    "uglifyjs-webpack-plugin": "^1.1.1",
    "watchpack": "^1.5.0",
    "webpack-sources": "^1.0.1"
  },
  "devDependencies": {
    "benchmark": "^2.1.1",
    "bundle-loader": "~0.5.0",
    "codacy-coverage": "^2.0.1",
    "coffee-loader": "^0.9.0",
    "coffeescript": "^1.10.0",
    "coveralls": "^2.11.2",
    "css-loader": "^0.28.3",
    "es6-promise-polyfill": "^1.1.1",
    "eslint": "^4.3.0",
    "eslint-plugin-node": "^5.1.1",
    "eslint-plugin-prettier": "^2.3.1",
    "express": "~4.13.1",
    "file-loader": "^1.1.6",
    "glob": "^7.1.2",
    "i18n-webpack-plugin": "^1.0.0",
    "istanbul": "^0.4.5",
    "jade": "^1.11.0",
    "jade-loader": "~0.8.0",
    "json-loader": "^0.5.7",
    "less": "^2.5.1",
    "less-loader": "^4.0.3",
    "lodash": "^4.17.4",
    "mocha": "^3.2.0",
    "mocha-lcov-reporter": "^1.0.0",
    "prettier": "^1.8.2",
    "raw-loader": "~0.5.0",
    "react": "^15.2.1",
    "react-dom": "^15.2.1",
    "rimraf": "^2.6.2",
    "script-loader": "~0.7.0",
    "should": "^11.1.1",
    "simple-git": "^1.65.0",
    "sinon": "^2.3.2",
    "style-loader": "^0.19.1",
    "url-loader": "^0.6.2",
    "val-loader": "^1.0.2",
    "vm-browserify": "~0.0.0",
    "webpack-dev-middleware": "^1.9.0",
    "worker-loader": "^1.1.0",
    "xxhashjs": "^0.2.1"
  },
  "engines": {
    "node": ">=6.11.5"
  },
  "repository": {
    "type": "git",
    "url": "https://github.com/webpack/webpack.git"
  },
  "homepage": "https://github.com/webpack/webpack",
  "main": "lib/webpack.js",
  "web": "lib/webpack.web.js",
  "bin": "./bin/webpack.js",
  "files": [
    "lib/",
    "bin/",
    "buildin/",
    "hot/",
    "web_modules/",
    "schemas/"
  ],
  "scripts": {
    "test": "mocha test/*.test.js test/*.unittest.js --max-old-space-size=4096 --harmony --trace-deprecation",
    "test:integration": "mocha test/*.test.js --max-old-space-size=4096 --harmony --trace-deprecation",
    "test:unit": "mocha test/*.unittest.js --max-old-space-size=4096 --harmony --trace-deprecation",
    "travis:integration": "npm run cover:init && npm run cover:integration && npm run cover:report-min",
    "travis:unit": "npm run cover:init && npm run cover:unit && npm run cover:report-min",
    "travis:lint": "npm run lint-files",
    "travis:benchmark": "npm run benchmark",
    "appveyor:integration": "npm run cover:init && npm run cover:integration && npm run cover:report-min",
    "appveyor:unit": "npm run cover:init && npm run cover:unit && npm run cover:report-min",
    "appveyor:benchmark": "npm run benchmark",
    "circleci:test": "node node_modules/mocha/bin/mocha --max-old-space-size=4096 --harmony --trace-deprecation test/*.test.js test/*.unittest.js",
    "circleci:lint": "npm run lint-files",
    "build:examples": "cd examples && node buildAll.js",
    "pretest": "npm run lint-files",
    "lint-files": "npm run lint && npm run schema-lint",
    "lint": "eslint lib bin hot buildin \"test/*.js\" \"test/**/webpack.config.js\" \"examples/**/webpack.config.js\" \"schemas/**/*.js\"",
    "fix": "npm run lint -- --fix",
    "pretty-files": "prettier \"lib/**.*\" \"bin/**.*\" \"hot/**.*\" \"buildin/**.*\" \"test/*.js\" \"test/**/webpack.config.js\" \"examples/**/webpack.config.js\" \"schemas/**/*.js\" --write",
    "schema-lint": "mocha test/*.lint.js --opts test/lint-mocha.opts",
    "benchmark": "mocha --max-old-space-size=4096 --harmony --trace-deprecation test/*.benchmark.js -R spec",
    "cover": "npm run cover:init && npm run cover:all && npm run cover:report",
    "cover:init": "rimraf coverage",
    "cover:all": "node --max-old-space-size=4096 --harmony --trace-deprecation ./node_modules/istanbul/lib/cli.js cover --report none node_modules/mocha/bin/_mocha -- test/*.test.js test/*.unittest.js",
    "cover:integration": "node --max-old-space-size=4096 --harmony --trace-deprecation ./node_modules/istanbul/lib/cli.js cover --report none node_modules/mocha/bin/_mocha -- test/*.test.js",
    "cover:unit": "node --max-old-space-size=4096 --harmony --trace-deprecation ./node_modules/istanbul/lib/cli.js cover --report none node_modules/mocha/bin/_mocha -- test/*.unittest.js",
    "cover:report": "istanbul report",
    "cover:report-min": "istanbul report --report lcovonly",
    "publish-patch": "npm run lint && mocha && npm version patch && git push && git push --tags && npm publish"
  }
}
""",
        "commander": """{
  "name": "commander",
  "version": "2.15.0",
  "description": "the complete solution for node.js command-line programs",
  "keywords": [
    "commander",
    "command",
    "option",
    "parser"
  ],
  "author": "TJ Holowaychuk <tj@vision-media.ca>",
  "license": "MIT",
  "repository": {
    "type": "git",
    "url": "https://github.com/tj/commander.js.git"
  },
  "scripts": {
    "lint": "eslint index.js",
    "test": "make test && npm run test-typings",
    "test-typings": "node_modules/typescript/bin/tsc -p tsconfig.json"
  },
  "main": "index",
  "files": [
    "index.js",
    "typings/index.d.ts"
  ],
  "dependencies": {},
  "devDependencies": {
    "@types/node": "^7.0.55",
    "eslint": "^3.19.0",
    "should": "^11.2.1",
    "sinon": "^2.4.1",
    "standard": "^10.0.3",
    "typescript": "^2.7.2"
  },
  "typings": "typings/index.d.ts"
}
""",
    }
